@@ -39,7 +39,19 @@ where
 
             if !eat!(self, " ")
                 && !is_one_of!(
-                    self, ",", "function", "ident", "percent", "str", "#", "url", "[", "{", "("
+                    self,
+                    ",",
+                    "/",
+                    "function",
+                    "ident",
+                    "dimension",
+                    "percent",
+                    "str",
+                    "#",
+                    "url",
+                    "[",
+                    "{",
+                    "("
                 )
             {
                 if self.ctx.recover_from_property_value
@@ -232,6 +244,15 @@ where
                 }));
             }
 
+            tok!("/") => {
+                bump!(self);
+
+                return Ok(Value::Delimiter(Delimiter {
+                    span: span!(self, span.lo),
+                    value: DelimiterValue::Solidus,
+                }));
+            }
+
             tok!("str") => return Ok(Value::Str(self.parse()?)),
 
             tok!("num") => return self.parse_numeric_value(),
@@ -846,6 +867,8 @@ where
                             modifiers.push(UrlModifier::Function(self.parse()?));
                         }
                         _ => {
+                            let span = self.input.cur_span()?;
+
                             return Err(Error::new(span, ErrorKind::Expected("ident or function")));
                         }
                     }
